# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/commanding.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/commanding.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobuf',
  serialized_pb=b'\n*yamcs/protobuf/commanding/commanding.proto\x12\x19yamcs.protobuf.commanding\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"`\n\tCommandId\x12\x16\n\x0egenerationTime\x18\x01 \x02(\x03\x12\x0e\n\x06origin\x18\x02 \x02(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x02(\x05\x12\x13\n\x0b\x63ommandName\x18\x04 \x01(\t\"\x8c\x03\n\x10\x43ommandQueueInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x34\n\x05state\x18\x04 \x01(\x0e\x32%.yamcs.protobuf.commanding.QueueState\x12\r\n\x05order\x18\t \x01(\x05\x12\r\n\x05users\x18\n \x03(\t\x12\x0e\n\x06groups\x18\x0b \x03(\t\x12L\n\x08minLevel\x18\x0c \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\x12\x12\n\ntcPatterns\x18\r \x03(\t\x12=\n\x07\x65ntries\x18\x0e \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\x12\x1d\n\x15\x61\x63\x63\x65ptedCommandsCount\x18\x0f \x01(\x05\x12\x1d\n\x15rejectedCommandsCount\x18\x10 \x01(\x05\"\xea\x02\n\x11\x43ommandQueueEntry\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x02 \x01(\t\x12\x11\n\tqueueName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x0e \x01(\t\x12\x0e\n\x06origin\x18\x0f \x01(\t\x12\x16\n\x0esequenceNumber\x18\x10 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\x11 \x01(\t\x12\x41\n\x0b\x61ssignments\x18\x12 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x12\x0e\n\x06\x62inary\x18\x06 \x01(\x0c\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x0f\n\x07\x63omment\x18\x0b \x01(\t\x12\x32\n\x0egenerationTime\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x1ependingTransmissionConstraints\x18\r \x01(\x08\"\xe8\x01\n\x11\x43ommandQueueEvent\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.yamcs.protobuf.commanding.CommandQueueEvent.Type\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"V\n\x04Type\x12\x11\n\rCOMMAND_ADDED\x10\x01\x12\x14\n\x10\x43OMMAND_REJECTED\x10\x02\x12\x10\n\x0c\x43OMMAND_SENT\x10\x03\x12\x13\n\x0f\x43OMMAND_UPDATED\x10\x04\"\xaf\x01\n\x13\x43ommandQueueRequest\x12>\n\tqueueInfo\x18\x01 \x01(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\x12@\n\nqueueEntry\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\x12\x16\n\x07rebuild\x18\x03 \x01(\x08:\x05\x66\x61lse\"i\n\x13\x43ommandSignificance\x12\x16\n\x0esequenceNumber\x18\x01 \x01(\x05\x12:\n\x0csignificance\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.SignificanceInfo\"\xb5\x01\n\x0eVerifierConfig\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x12J\n\x0b\x63heckWindow\x18\x03 \x01(\x0b\x32\x35.yamcs.protobuf.commanding.VerifierConfig.CheckWindow\x1a\x46\n\x0b\x43heckWindow\x12\x1b\n\x13timeToStartChecking\x18\x01 \x01(\x03\x12\x1a\n\x12timeToStopChecking\x18\x02 \x01(\x03\"[\n\x17\x43ommandHistoryAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x0c\n\x04time\x18\x03 \x01(\x03\"Z\n\x11\x43ommandAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x11\n\tuserInput\x18\x03 \x01(\x08\"\xce\x03\n\x13\x43ommandHistoryEntry\x12\n\n\x02id\x18\x07 \x01(\t\x12\x13\n\x0b\x63ommandName\x18\x08 \x01(\t\x12L\n\x07\x61liases\x18\x0c \x03(\x0b\x32;.yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry\x12\x0e\n\x06origin\x18\t \x01(\t\x12\x16\n\x0esequenceNumber\x18\n \x01(\x05\x12\x37\n\tcommandId\x18\x01 \x01(\x0b\x32$.yamcs.protobuf.commanding.CommandId\x12@\n\x04\x61ttr\x18\x03 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0b\x61ssignments\x18\x0b \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*4\n\nQueueState\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07\x45NABLED\x10\x03\x42\x14\n\x12org.yamcs.protobuf'
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_QUEUESTATE = _descriptor.EnumDescriptor(
  name='QueueState',
  full_name='yamcs.protobuf.commanding.QueueState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2380,
  serialized_end=2432,
)
_sym_db.RegisterEnumDescriptor(_QUEUESTATE)

QueueState = enum_type_wrapper.EnumTypeWrapper(_QUEUESTATE)
BLOCKED = 1
DISABLED = 2
ENABLED = 3


_COMMANDQUEUEEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.commanding.CommandQueueEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMAND_ADDED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_REJECTED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_SENT', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_UPDATED', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1173,
  serialized_end=1259,
)
_sym_db.RegisterEnumDescriptor(_COMMANDQUEUEEVENT_TYPE)


_COMMANDID = _descriptor.Descriptor(
  name='CommandId',
  full_name='yamcs.protobuf.commanding.CommandId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandId.generationTime', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandId.origin', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandId.sequenceNumber', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandId.commandName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=260,
)


_COMMANDQUEUEINFO = _descriptor.Descriptor(
  name='CommandQueueInfo',
  full_name='yamcs.protobuf.commanding.CommandQueueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.CommandQueueInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.commanding.CommandQueueInfo.processorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandQueueInfo.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.CommandQueueInfo.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.commanding.CommandQueueInfo.order', index=4,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='yamcs.protobuf.commanding.CommandQueueInfo.users', index=5,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='yamcs.protobuf.commanding.CommandQueueInfo.groups', index=6,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minLevel', full_name='yamcs.protobuf.commanding.CommandQueueInfo.minLevel', index=7,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcPatterns', full_name='yamcs.protobuf.commanding.CommandQueueInfo.tcPatterns', index=8,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yamcs.protobuf.commanding.CommandQueueInfo.entries', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acceptedCommandsCount', full_name='yamcs.protobuf.commanding.CommandQueueInfo.acceptedCommandsCount', index=10,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rejectedCommandsCount', full_name='yamcs.protobuf.commanding.CommandQueueInfo.rejectedCommandsCount', index=11,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=659,
)


_COMMANDQUEUEENTRY = _descriptor.Descriptor(
  name='CommandQueueEntry',
  full_name='yamcs.protobuf.commanding.CommandQueueEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.CommandQueueEntry.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.processorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queueName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.queueName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.CommandQueueEntry.id', index=3,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandQueueEntry.origin', index=4,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandQueueEntry.sequenceNumber', index=5,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.commandName', index=6,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.CommandQueueEntry.assignments', index=7,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.commanding.CommandQueueEntry.binary', index=8,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.CommandQueueEntry.username', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.commanding.CommandQueueEntry.comment', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandQueueEntry.generationTime', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pendingTransmissionConstraints', full_name='yamcs.protobuf.commanding.CommandQueueEntry.pendingTransmissionConstraints', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=1024,
)


_COMMANDQUEUEEVENT = _descriptor.Descriptor(
  name='CommandQueueEvent',
  full_name='yamcs.protobuf.commanding.CommandQueueEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.commanding.CommandQueueEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.commanding.CommandQueueEvent.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDQUEUEEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1027,
  serialized_end=1259,
)


_COMMANDQUEUEREQUEST = _descriptor.Descriptor(
  name='CommandQueueRequest',
  full_name='yamcs.protobuf.commanding.CommandQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueInfo', full_name='yamcs.protobuf.commanding.CommandQueueRequest.queueInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queueEntry', full_name='yamcs.protobuf.commanding.CommandQueueRequest.queueEntry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rebuild', full_name='yamcs.protobuf.commanding.CommandQueueRequest.rebuild', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1437,
)


_COMMANDSIGNIFICANCE = _descriptor.Descriptor(
  name='CommandSignificance',
  full_name='yamcs.protobuf.commanding.CommandSignificance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandSignificance.sequenceNumber', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='significance', full_name='yamcs.protobuf.commanding.CommandSignificance.significance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1544,
)


_VERIFIERCONFIG_CHECKWINDOW = _descriptor.Descriptor(
  name='CheckWindow',
  full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeToStartChecking', full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow.timeToStartChecking', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeToStopChecking', full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow.timeToStopChecking', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1728,
)

_VERIFIERCONFIG = _descriptor.Descriptor(
  name='VerifierConfig',
  full_name='yamcs.protobuf.commanding.VerifierConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable', full_name='yamcs.protobuf.commanding.VerifierConfig.disable', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checkWindow', full_name='yamcs.protobuf.commanding.VerifierConfig.checkWindow', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VERIFIERCONFIG_CHECKWINDOW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1728,
)


_COMMANDHISTORYATTRIBUTE = _descriptor.Descriptor(
  name='CommandHistoryAttribute',
  full_name='yamcs.protobuf.commanding.CommandHistoryAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1821,
)


_COMMANDASSIGNMENT = _descriptor.Descriptor(
  name='CommandAssignment',
  full_name='yamcs.protobuf.commanding.CommandAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandAssignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandAssignment.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userInput', full_name='yamcs.protobuf.commanding.CommandAssignment.userInput', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=1913,
)


_COMMANDHISTORYENTRY_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2332,
  serialized_end=2378,
)

_COMMANDHISTORYENTRY = _descriptor.Descriptor(
  name='CommandHistoryEntry',
  full_name='yamcs.protobuf.commanding.CommandHistoryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.id', index=0,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.commandName', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.aliases', index=2,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.origin', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.sequenceNumber', index=4,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.commandId', index=5,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attr', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.attr', index=6,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.generationTime', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.assignments', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDHISTORYENTRY_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2378,
)

_COMMANDQUEUEINFO.fields_by_name['state'].enum_type = _QUEUESTATE
_COMMANDQUEUEINFO.fields_by_name['minLevel'].enum_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
_COMMANDQUEUEINFO.fields_by_name['entries'].message_type = _COMMANDQUEUEENTRY
_COMMANDQUEUEENTRY.fields_by_name['assignments'].message_type = _COMMANDASSIGNMENT
_COMMANDQUEUEENTRY.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDQUEUEEVENT.fields_by_name['type'].enum_type = _COMMANDQUEUEEVENT_TYPE
_COMMANDQUEUEEVENT.fields_by_name['data'].message_type = _COMMANDQUEUEENTRY
_COMMANDQUEUEEVENT_TYPE.containing_type = _COMMANDQUEUEEVENT
_COMMANDQUEUEREQUEST.fields_by_name['queueInfo'].message_type = _COMMANDQUEUEINFO
_COMMANDQUEUEREQUEST.fields_by_name['queueEntry'].message_type = _COMMANDQUEUEENTRY
_COMMANDSIGNIFICANCE.fields_by_name['significance'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO
_VERIFIERCONFIG_CHECKWINDOW.containing_type = _VERIFIERCONFIG
_VERIFIERCONFIG.fields_by_name['checkWindow'].message_type = _VERIFIERCONFIG_CHECKWINDOW
_COMMANDHISTORYATTRIBUTE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_COMMANDASSIGNMENT.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_COMMANDHISTORYENTRY_ALIASESENTRY.containing_type = _COMMANDHISTORYENTRY
_COMMANDHISTORYENTRY.fields_by_name['aliases'].message_type = _COMMANDHISTORYENTRY_ALIASESENTRY
_COMMANDHISTORYENTRY.fields_by_name['commandId'].message_type = _COMMANDID
_COMMANDHISTORYENTRY.fields_by_name['attr'].message_type = _COMMANDHISTORYATTRIBUTE
_COMMANDHISTORYENTRY.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDHISTORYENTRY.fields_by_name['assignments'].message_type = _COMMANDASSIGNMENT
DESCRIPTOR.message_types_by_name['CommandId'] = _COMMANDID
DESCRIPTOR.message_types_by_name['CommandQueueInfo'] = _COMMANDQUEUEINFO
DESCRIPTOR.message_types_by_name['CommandQueueEntry'] = _COMMANDQUEUEENTRY
DESCRIPTOR.message_types_by_name['CommandQueueEvent'] = _COMMANDQUEUEEVENT
DESCRIPTOR.message_types_by_name['CommandQueueRequest'] = _COMMANDQUEUEREQUEST
DESCRIPTOR.message_types_by_name['CommandSignificance'] = _COMMANDSIGNIFICANCE
DESCRIPTOR.message_types_by_name['VerifierConfig'] = _VERIFIERCONFIG
DESCRIPTOR.message_types_by_name['CommandHistoryAttribute'] = _COMMANDHISTORYATTRIBUTE
DESCRIPTOR.message_types_by_name['CommandAssignment'] = _COMMANDASSIGNMENT
DESCRIPTOR.message_types_by_name['CommandHistoryEntry'] = _COMMANDHISTORYENTRY
DESCRIPTOR.enum_types_by_name['QueueState'] = _QUEUESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommandId = _reflection.GeneratedProtocolMessageType('CommandId', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDID,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandId)
  })
_sym_db.RegisterMessage(CommandId)

CommandQueueInfo = _reflection.GeneratedProtocolMessageType('CommandQueueInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEINFO,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueInfo)
  })
_sym_db.RegisterMessage(CommandQueueInfo)

CommandQueueEntry = _reflection.GeneratedProtocolMessageType('CommandQueueEntry', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEENTRY,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueEntry)
  })
_sym_db.RegisterMessage(CommandQueueEntry)

CommandQueueEvent = _reflection.GeneratedProtocolMessageType('CommandQueueEvent', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEEVENT,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueEvent)
  })
_sym_db.RegisterMessage(CommandQueueEvent)

CommandQueueRequest = _reflection.GeneratedProtocolMessageType('CommandQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueRequest)
  })
_sym_db.RegisterMessage(CommandQueueRequest)

CommandSignificance = _reflection.GeneratedProtocolMessageType('CommandSignificance', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSIGNIFICANCE,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandSignificance)
  })
_sym_db.RegisterMessage(CommandSignificance)

VerifierConfig = _reflection.GeneratedProtocolMessageType('VerifierConfig', (_message.Message,), {

  'CheckWindow' : _reflection.GeneratedProtocolMessageType('CheckWindow', (_message.Message,), {
    'DESCRIPTOR' : _VERIFIERCONFIG_CHECKWINDOW,
    '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.VerifierConfig.CheckWindow)
    })
  ,
  'DESCRIPTOR' : _VERIFIERCONFIG,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.VerifierConfig)
  })
_sym_db.RegisterMessage(VerifierConfig)
_sym_db.RegisterMessage(VerifierConfig.CheckWindow)

CommandHistoryAttribute = _reflection.GeneratedProtocolMessageType('CommandHistoryAttribute', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDHISTORYATTRIBUTE,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryAttribute)
  })
_sym_db.RegisterMessage(CommandHistoryAttribute)

CommandAssignment = _reflection.GeneratedProtocolMessageType('CommandAssignment', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDASSIGNMENT,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandAssignment)
  })
_sym_db.RegisterMessage(CommandAssignment)

CommandHistoryEntry = _reflection.GeneratedProtocolMessageType('CommandHistoryEntry', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMANDHISTORYENTRY_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _COMMANDHISTORYENTRY,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryEntry)
  })
_sym_db.RegisterMessage(CommandHistoryEntry)
_sym_db.RegisterMessage(CommandHistoryEntry.AliasesEntry)


DESCRIPTOR._options = None
_COMMANDHISTORYENTRY_ALIASESENTRY._options = None
# @@protoc_insertion_point(module_scope)
