# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/cop1/cop1.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/cop1/cop1.proto',
  package='yamcs.protobuf.cop1',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\tCop1ProtoP\001',
  serialized_pb=b'\n\x1eyamcs/protobuf/cop1/cop1.proto\x12\x13yamcs.protobuf.cop1\x1a\x1byamcs/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x11InitializeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x35\n\x04type\x18\x03 \x01(\x0e\x32\'.yamcs.protobuf.cop1.InitializationType\x12\"\n\x1a\x63lcwCheckInitializeTimeout\x18\x04 \x01(\x04\x12\n\n\x02vR\x18\x05 \x01(\r\"j\n\x13UpdateConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x33\n\ncop1Config\x18\x03 \x01(\x0b\x32\x1f.yamcs.protobuf.cop1.Cop1Config\"2\n\x10GetConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"2\n\x10GetStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"/\n\rResumeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"F\n\x0e\x44isableRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x14\n\x0csetBypassAll\x18\x03 \x01(\x08\"x\n\x04\x43lcw\x12\x31\n\rreceptionTime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07lockout\x18\x02 \x01(\x08\x12\x0c\n\x04wait\x18\x03 \x01(\x08\x12\x12\n\nretransmit\x18\x04 \x01(\x08\x12\n\n\x02nR\x18\x05 \x01(\r\"\x95\x02\n\nCop1Status\x12\x0c\n\x04link\x18\x0b \x01(\t\x12\x12\n\ncop1Active\x18\x01 \x01(\x08\x12\x14\n\x0csetBypassAll\x18\x02 \x01(\x08\x12\'\n\x04\x63lcw\x18\x03 \x01(\x0b\x32\x19.yamcs.protobuf.cop1.Clcw\x12-\n\x05state\x18\x04 \x01(\x0e\x32\x1e.yamcs.protobuf.cop1.Cop1State\x12\n\n\x02vS\x18\x05 \x01(\r\x12\x0b\n\x03nnR\x18\x06 \x01(\r\x12\x16\n\x0ewaitQueueNumTC\x18\x07 \x01(\r\x12\x1a\n\x12sentQueueNumFrames\x18\x08 \x01(\r\x12\x19\n\x11outQueueNumFrames\x18\t \x01(\r\x12\x0f\n\x07txCount\x18\n \x01(\r\"\x9f\x01\n\nCop1Config\x12\x0c\n\x04vcId\x18\x01 \x01(\r\x12\x1a\n\x12\x62\x64\x41\x62solutePriority\x18\x03 \x01(\x08\x12\x13\n\x0bwindowWidth\x18\x04 \x01(\r\x12\x35\n\x0btimeoutType\x18\x05 \x01(\x0e\x32 .yamcs.protobuf.cop1.TimeoutType\x12\x0f\n\x07txLimit\x18\x06 \x01(\r\x12\n\n\x02t1\x18\x07 \x01(\x04\"8\n\x16SubscribeStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t*Y\n\x12InitializationType\x12\x13\n\x0fWITH_CLCW_CHECK\x10\x01\x12\x16\n\x12WITHOUT_CLCW_CHECK\x10\x02\x12\n\n\x06UNLOCK\x10\x03\x12\n\n\x06SET_VR\x10\x04*\xa7\x01\n\tCop1State\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1b\n\x17RETRANSMIT_WITHOUT_WAIT\x10\x02\x12\x18\n\x14RETRANSMIT_WITH_WAIT\x10\x03\x12\x1b\n\x17INITIALIZING_WITHOUT_BC\x10\x04\x12\x18\n\x14INITIALIZING_WITH_BC\x10\x05\x12\x11\n\rUNINITIALIZED\x10\x06\x12\r\n\tSUSPENDED\x10\x07*,\n\x0bTimeoutType\x12\x10\n\x0cUNINITIALIZE\x10\x00\x12\x0b\n\x07SUSPEND\x10\x01\x32\xf8\x06\n\x07\x43op1Api\x12}\n\nInitialize\x12&.yamcs.protobuf.cop1.InitializeRequest\x1a\x16.google.protobuf.Empty\"/\x8a\x92\x03+\x1a&/api/cop1/{instance}/{link}:initialize:\x01*\x12n\n\x06Resume\x12\".yamcs.protobuf.cop1.ResumeRequest\x1a\x16.google.protobuf.Empty\"(\x8a\x92\x03$\x1a\"/api/cop1/{instance}/{link}:resume\x12t\n\x07\x44isable\x12#.yamcs.protobuf.cop1.DisableRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(\x1a#/api/cop1/{instance}/{link}:disable:\x01*\x12\x8f\x01\n\x0cUpdateConfig\x12(.yamcs.protobuf.cop1.UpdateConfigRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Config\"4\x8a\x92\x03\x30*\"/api/cop1/{instance}/{link}/config:\ncop1Config\x12}\n\tGetConfig\x12%.yamcs.protobuf.cop1.GetConfigRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Config\"(\x8a\x92\x03$\n\"/api/cop1/{instance}/{link}/config\x12}\n\tGetStatus\x12%.yamcs.protobuf.cop1.GetStatusRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Status\"(\x8a\x92\x03$\n\"/api/cop1/{instance}/{link}/status\x12m\n\x0fSubscribeStatus\x12+.yamcs.protobuf.cop1.SubscribeStatusRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Status\"\n\xda\x92\x03\x06\n\x04\x63op10\x01\x1a\t\x82\x80\x01\x05\x43OP-1B!\n\x12org.yamcs.protobufB\tCop1ProtoP\x01'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_INITIALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='InitializationType',
  full_name='yamcs.protobuf.cop1.InitializationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WITH_CLCW_CHECK', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHOUT_CLCW_CHECK', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNLOCK', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_VR', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1258,
  serialized_end=1347,
)
_sym_db.RegisterEnumDescriptor(_INITIALIZATIONTYPE)

InitializationType = enum_type_wrapper.EnumTypeWrapper(_INITIALIZATIONTYPE)
_COP1STATE = _descriptor.EnumDescriptor(
  name='Cop1State',
  full_name='yamcs.protobuf.cop1.Cop1State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETRANSMIT_WITHOUT_WAIT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETRANSMIT_WITH_WAIT', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING_WITHOUT_BC', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING_WITH_BC', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNINITIALIZED', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUSPENDED', index=6, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1350,
  serialized_end=1517,
)
_sym_db.RegisterEnumDescriptor(_COP1STATE)

Cop1State = enum_type_wrapper.EnumTypeWrapper(_COP1STATE)
_TIMEOUTTYPE = _descriptor.EnumDescriptor(
  name='TimeoutType',
  full_name='yamcs.protobuf.cop1.TimeoutType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNINITIALIZE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUSPEND', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1519,
  serialized_end=1563,
)
_sym_db.RegisterEnumDescriptor(_TIMEOUTTYPE)

TimeoutType = enum_type_wrapper.EnumTypeWrapper(_TIMEOUTTYPE)
WITH_CLCW_CHECK = 1
WITHOUT_CLCW_CHECK = 2
UNLOCK = 3
SET_VR = 4
ACTIVE = 1
RETRANSMIT_WITHOUT_WAIT = 2
RETRANSMIT_WITH_WAIT = 3
INITIALIZING_WITHOUT_BC = 4
INITIALIZING_WITH_BC = 5
UNINITIALIZED = 6
SUSPENDED = 7
UNINITIALIZE = 0
SUSPEND = 1



_INITIALIZEREQUEST = _descriptor.Descriptor(
  name='InitializeRequest',
  full_name='yamcs.protobuf.cop1.InitializeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.InitializeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.InitializeRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.cop1.InitializeRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clcwCheckInitializeTimeout', full_name='yamcs.protobuf.cop1.InitializeRequest.clcwCheckInitializeTimeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vR', full_name='yamcs.protobuf.cop1.InitializeRequest.vR', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=301,
)


_UPDATECONFIGREQUEST = _descriptor.Descriptor(
  name='UpdateConfigRequest',
  full_name='yamcs.protobuf.cop1.UpdateConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cop1Config', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.cop1Config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=409,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='yamcs.protobuf.cop1.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.GetConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.GetConfigRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=461,
)


_GETSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStatusRequest',
  full_name='yamcs.protobuf.cop1.GetStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.GetStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.GetStatusRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=513,
)


_RESUMEREQUEST = _descriptor.Descriptor(
  name='ResumeRequest',
  full_name='yamcs.protobuf.cop1.ResumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.ResumeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.ResumeRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=562,
)


_DISABLEREQUEST = _descriptor.Descriptor(
  name='DisableRequest',
  full_name='yamcs.protobuf.cop1.DisableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.DisableRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.DisableRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setBypassAll', full_name='yamcs.protobuf.cop1.DisableRequest.setBypassAll', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=634,
)


_CLCW = _descriptor.Descriptor(
  name='Clcw',
  full_name='yamcs.protobuf.cop1.Clcw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receptionTime', full_name='yamcs.protobuf.cop1.Clcw.receptionTime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lockout', full_name='yamcs.protobuf.cop1.Clcw.lockout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait', full_name='yamcs.protobuf.cop1.Clcw.wait', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retransmit', full_name='yamcs.protobuf.cop1.Clcw.retransmit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nR', full_name='yamcs.protobuf.cop1.Clcw.nR', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=756,
)


_COP1STATUS = _descriptor.Descriptor(
  name='Cop1Status',
  full_name='yamcs.protobuf.cop1.Cop1Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.Cop1Status.link', index=0,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cop1Active', full_name='yamcs.protobuf.cop1.Cop1Status.cop1Active', index=1,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setBypassAll', full_name='yamcs.protobuf.cop1.Cop1Status.setBypassAll', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clcw', full_name='yamcs.protobuf.cop1.Cop1Status.clcw', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.cop1.Cop1Status.state', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vS', full_name='yamcs.protobuf.cop1.Cop1Status.vS', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nnR', full_name='yamcs.protobuf.cop1.Cop1Status.nnR', index=6,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waitQueueNumTC', full_name='yamcs.protobuf.cop1.Cop1Status.waitQueueNumTC', index=7,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentQueueNumFrames', full_name='yamcs.protobuf.cop1.Cop1Status.sentQueueNumFrames', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outQueueNumFrames', full_name='yamcs.protobuf.cop1.Cop1Status.outQueueNumFrames', index=9,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txCount', full_name='yamcs.protobuf.cop1.Cop1Status.txCount', index=10,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1036,
)


_COP1CONFIG = _descriptor.Descriptor(
  name='Cop1Config',
  full_name='yamcs.protobuf.cop1.Cop1Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcId', full_name='yamcs.protobuf.cop1.Cop1Config.vcId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bdAbsolutePriority', full_name='yamcs.protobuf.cop1.Cop1Config.bdAbsolutePriority', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windowWidth', full_name='yamcs.protobuf.cop1.Cop1Config.windowWidth', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeoutType', full_name='yamcs.protobuf.cop1.Cop1Config.timeoutType', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txLimit', full_name='yamcs.protobuf.cop1.Cop1Config.txLimit', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t1', full_name='yamcs.protobuf.cop1.Cop1Config.t1', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1198,
)


_SUBSCRIBESTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeStatusRequest',
  full_name='yamcs.protobuf.cop1.SubscribeStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.SubscribeStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.SubscribeStatusRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1256,
)

_INITIALIZEREQUEST.fields_by_name['type'].enum_type = _INITIALIZATIONTYPE
_UPDATECONFIGREQUEST.fields_by_name['cop1Config'].message_type = _COP1CONFIG
_CLCW.fields_by_name['receptionTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COP1STATUS.fields_by_name['clcw'].message_type = _CLCW
_COP1STATUS.fields_by_name['state'].enum_type = _COP1STATE
_COP1CONFIG.fields_by_name['timeoutType'].enum_type = _TIMEOUTTYPE
DESCRIPTOR.message_types_by_name['InitializeRequest'] = _INITIALIZEREQUEST
DESCRIPTOR.message_types_by_name['UpdateConfigRequest'] = _UPDATECONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ResumeRequest'] = _RESUMEREQUEST
DESCRIPTOR.message_types_by_name['DisableRequest'] = _DISABLEREQUEST
DESCRIPTOR.message_types_by_name['Clcw'] = _CLCW
DESCRIPTOR.message_types_by_name['Cop1Status'] = _COP1STATUS
DESCRIPTOR.message_types_by_name['Cop1Config'] = _COP1CONFIG
DESCRIPTOR.message_types_by_name['SubscribeStatusRequest'] = _SUBSCRIBESTATUSREQUEST
DESCRIPTOR.enum_types_by_name['InitializationType'] = _INITIALIZATIONTYPE
DESCRIPTOR.enum_types_by_name['Cop1State'] = _COP1STATE
DESCRIPTOR.enum_types_by_name['TimeoutType'] = _TIMEOUTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitializeRequest = _reflection.GeneratedProtocolMessageType('InitializeRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.InitializeRequest)
  })
_sym_db.RegisterMessage(InitializeRequest)

UpdateConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.UpdateConfigRequest)
  })
_sym_db.RegisterMessage(UpdateConfigRequest)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.GetStatusRequest)
  })
_sym_db.RegisterMessage(GetStatusRequest)

ResumeRequest = _reflection.GeneratedProtocolMessageType('ResumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.ResumeRequest)
  })
_sym_db.RegisterMessage(ResumeRequest)

DisableRequest = _reflection.GeneratedProtocolMessageType('DisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.DisableRequest)
  })
_sym_db.RegisterMessage(DisableRequest)

Clcw = _reflection.GeneratedProtocolMessageType('Clcw', (_message.Message,), {
  'DESCRIPTOR' : _CLCW,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Clcw)
  })
_sym_db.RegisterMessage(Clcw)

Cop1Status = _reflection.GeneratedProtocolMessageType('Cop1Status', (_message.Message,), {
  'DESCRIPTOR' : _COP1STATUS,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Cop1Status)
  })
_sym_db.RegisterMessage(Cop1Status)

Cop1Config = _reflection.GeneratedProtocolMessageType('Cop1Config', (_message.Message,), {
  'DESCRIPTOR' : _COP1CONFIG,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Cop1Config)
  })
_sym_db.RegisterMessage(Cop1Config)

SubscribeStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBESTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.SubscribeStatusRequest)
  })
_sym_db.RegisterMessage(SubscribeStatusRequest)


DESCRIPTOR._options = None

_COP1API = _descriptor.ServiceDescriptor(
  name='Cop1Api',
  full_name='yamcs.protobuf.cop1.Cop1Api',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\200\001\005COP-1',
  serialized_start=1566,
  serialized_end=2454,
  methods=[
  _descriptor.MethodDescriptor(
    name='Initialize',
    full_name='yamcs.protobuf.cop1.Cop1Api.Initialize',
    index=0,
    containing_service=None,
    input_type=_INITIALIZEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003+\032&/api/cop1/{instance}/{link}:initialize:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='Resume',
    full_name='yamcs.protobuf.cop1.Cop1Api.Resume',
    index=1,
    containing_service=None,
    input_type=_RESUMEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003$\032\"/api/cop1/{instance}/{link}:resume',
  ),
  _descriptor.MethodDescriptor(
    name='Disable',
    full_name='yamcs.protobuf.cop1.Cop1Api.Disable',
    index=2,
    containing_service=None,
    input_type=_DISABLEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003(\032#/api/cop1/{instance}/{link}:disable:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateConfig',
    full_name='yamcs.protobuf.cop1.Cop1Api.UpdateConfig',
    index=3,
    containing_service=None,
    input_type=_UPDATECONFIGREQUEST,
    output_type=_COP1CONFIG,
    serialized_options=b'\212\222\0030*\"/api/cop1/{instance}/{link}/config:\ncop1Config',
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='yamcs.protobuf.cop1.Cop1Api.GetConfig',
    index=4,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_COP1CONFIG,
    serialized_options=b'\212\222\003$\n\"/api/cop1/{instance}/{link}/config',
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='yamcs.protobuf.cop1.Cop1Api.GetStatus',
    index=5,
    containing_service=None,
    input_type=_GETSTATUSREQUEST,
    output_type=_COP1STATUS,
    serialized_options=b'\212\222\003$\n\"/api/cop1/{instance}/{link}/status',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStatus',
    full_name='yamcs.protobuf.cop1.Cop1Api.SubscribeStatus',
    index=6,
    containing_service=None,
    input_type=_SUBSCRIBESTATUSREQUEST,
    output_type=_COP1STATUS,
    serialized_options=b'\332\222\003\006\n\004cop1',
  ),
])
_sym_db.RegisterServiceDescriptor(_COP1API)

DESCRIPTOR.services_by_name['Cop1Api'] = _COP1API

# @@protoc_insertion_point(module_scope)
