# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/activities/activities.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/activities/activities.proto',
  package='yamcs.protobuf.activities',
  syntax='proto2',
  serialized_options=b'\n\035org.yamcs.protobuf.activitiesB\017ActivitiesProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/activities/activities.proto\x12\x19yamcs.protobuf.activities\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"^\n\x16\x41\x63tivityDefinitionInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12%\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\"\xb9\x02\n\x0c\x41\x63tivityInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03seq\x18\x03 \x01(\r\x12\x39\n\x06status\x18\x04 \x01(\x0e\x32).yamcs.protobuf.activities.ActivityStatus\x12\x11\n\tstartedBy\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12%\n\x04\x61rgs\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x64\x65tail\x18\x08 \x01(\t\x12(\n\x04stop\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tstoppedBy\x18\n \x01(\t\x12\x15\n\rfailureReason\x18\x0b \x01(\t\"T\n\x0c\x45xecutorInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x98\x01\n\x0f\x41\x63tivityLogInfo\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06source\x18\x02 \x01(\t\x12:\n\x05level\x18\x03 \x01(\x0e\x32+.yamcs.protobuf.activities.ActivityLogLevel\x12\x0f\n\x07message\x18\x04 \x01(\t*H\n\x0e\x41\x63tivityStatus\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x0e\n\nSUCCESSFUL\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04*4\n\x10\x41\x63tivityLogLevel\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42\x32\n\x1dorg.yamcs.protobuf.activitiesB\x0f\x41\x63tivitiesProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ACTIVITYSTATUS = _descriptor.EnumDescriptor(
  name='ActivityStatus',
  full_name='yamcs.protobuf.activities.ActivityStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESSFUL', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=789,
  serialized_end=861,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYSTATUS)

ActivityStatus = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYSTATUS)
_ACTIVITYLOGLEVEL = _descriptor.EnumDescriptor(
  name='ActivityLogLevel',
  full_name='yamcs.protobuf.activities.ActivityLogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFO', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=863,
  serialized_end=915,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYLOGLEVEL)

ActivityLogLevel = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYLOGLEVEL)
RUNNING = 1
CANCELLED = 2
SUCCESSFUL = 3
FAILED = 4
INFO = 1
WARNING = 2
ERROR = 3



_ACTIVITYDEFINITIONINFO = _descriptor.Descriptor(
  name='ActivityDefinitionInfo',
  full_name='yamcs.protobuf.activities.ActivityDefinitionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.args', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=230,
)


_ACTIVITYINFO = _descriptor.Descriptor(
  name='ActivityInfo',
  full_name='yamcs.protobuf.activities.ActivityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.activities.ActivityInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.activities.ActivityInfo.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.protobuf.activities.ActivityInfo.seq', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.activities.ActivityInfo.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startedBy', full_name='yamcs.protobuf.activities.ActivityInfo.startedBy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ActivityInfo.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.activities.ActivityInfo.args', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='yamcs.protobuf.activities.ActivityInfo.detail', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.activities.ActivityInfo.stop', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stoppedBy', full_name='yamcs.protobuf.activities.ActivityInfo.stoppedBy', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.activities.ActivityInfo.failureReason', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=546,
)


_EXECUTORINFO = _descriptor.Descriptor(
  name='ExecutorInfo',
  full_name='yamcs.protobuf.activities.ExecutorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ExecutorInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayName', full_name='yamcs.protobuf.activities.ExecutorInfo.displayName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.activities.ExecutorInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon', full_name='yamcs.protobuf.activities.ExecutorInfo.icon', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=632,
)


_ACTIVITYLOGINFO = _descriptor.Descriptor(
  name='ActivityLogInfo',
  full_name='yamcs.protobuf.activities.ActivityLogInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.activities.ActivityLogInfo.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.activities.ActivityLogInfo.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.activities.ActivityLogInfo.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.activities.ActivityLogInfo.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=787,
)

_ACTIVITYDEFINITIONINFO.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ACTIVITYINFO.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYINFO.fields_by_name['status'].enum_type = _ACTIVITYSTATUS
_ACTIVITYINFO.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ACTIVITYINFO.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYLOGINFO.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYLOGINFO.fields_by_name['level'].enum_type = _ACTIVITYLOGLEVEL
DESCRIPTOR.message_types_by_name['ActivityDefinitionInfo'] = _ACTIVITYDEFINITIONINFO
DESCRIPTOR.message_types_by_name['ActivityInfo'] = _ACTIVITYINFO
DESCRIPTOR.message_types_by_name['ExecutorInfo'] = _EXECUTORINFO
DESCRIPTOR.message_types_by_name['ActivityLogInfo'] = _ACTIVITYLOGINFO
DESCRIPTOR.enum_types_by_name['ActivityStatus'] = _ACTIVITYSTATUS
DESCRIPTOR.enum_types_by_name['ActivityLogLevel'] = _ACTIVITYLOGLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivityDefinitionInfo = _reflection.GeneratedProtocolMessageType('ActivityDefinitionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYDEFINITIONINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityDefinitionInfo)
  })
_sym_db.RegisterMessage(ActivityDefinitionInfo)

ActivityInfo = _reflection.GeneratedProtocolMessageType('ActivityInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityInfo)
  })
_sym_db.RegisterMessage(ActivityInfo)

ExecutorInfo = _reflection.GeneratedProtocolMessageType('ExecutorInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTORINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ExecutorInfo)
  })
_sym_db.RegisterMessage(ExecutorInfo)

ActivityLogInfo = _reflection.GeneratedProtocolMessageType('ActivityLogInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLOGINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityLogInfo)
  })
_sym_db.RegisterMessage(ActivityLogInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
