# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/index_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/index_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\021IndexServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/archive/index_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xc5\x01\n\x1eListCommandHistoryIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xbe\x01\n\x15ListEventIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x03(\t\"\xbd\x01\n\x16ListPacketIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xc1\x01\n\x19ListParameterIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\r\n\x05group\x18\x07 \x03(\t\"\xb5\x01\n\x1cListCompletenessIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x05 \x01(\t\"]\n\rIndexResponse\x12\x31\n\x05group\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexGroup\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"j\n\nIndexGroup\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x31\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexEntry\"[\n\nIndexEntry\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x10\n\x08seqStart\x18\x04 \x01(\x03\x12\x0f\n\x07seqStop\x18\x05 \x01(\x03\"\xa3\x01\n\x18StreamPacketIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05names\x18\x04 \x03(\t\x12\x11\n\tmergeTime\x18\x05 \x01(\r\"\x97\x01\n\x1bStreamParameterIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x95\x01\n\x19StreamCommandIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x93\x01\n\x17StreamEventIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x9a\x01\n\x1eStreamCompletenessIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\r\"\x81\x01\n\x18RebuildCcsdsIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe8\r\n\nIndexesApi\x12\xa5\x01\n\x17ListCommandHistoryIndex\x12\x36.yamcs.protobuf.archive.ListCommandHistoryIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"+\x8a\x92\x03\'\n%/api/archive/{instance}/command-index\x12\x91\x01\n\x0eListEventIndex\x12-.yamcs.protobuf.archive.ListEventIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\")\x8a\x92\x03%\n#/api/archive/{instance}/event-index\x12\x94\x01\n\x0fListPacketIndex\x12..yamcs.protobuf.archive.ListPacketIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"*\x8a\x92\x03&\n$/api/archive/{instance}/packet-index\x12\x9d\x01\n\x12ListParameterIndex\x12\x31.yamcs.protobuf.archive.ListParameterIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"-\x8a\x92\x03)\n\'/api/archive/{instance}/parameter-index\x12\xa6\x01\n\x15ListCompletenessIndex\x12\x34.yamcs.protobuf.archive.ListCompletenessIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"0\x8a\x92\x03,\n*/api/archive/{instance}/completeness-index\x12\x9a\x01\n\x11StreamPacketIndex\x12\x30.yamcs.protobuf.archive.StreamPacketIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"2\x8a\x92\x03.\x1a)/api/archive/{instance}:streamPacketIndex:\x01*0\x01\x12\xa3\x01\n\x14StreamParameterIndex\x12\x33.yamcs.protobuf.archive.StreamParameterIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"5\x8a\x92\x03\x31\x1a,/api/archive/{instance}:streamParameterIndex:\x01*0\x01\x12\x9d\x01\n\x12StreamCommandIndex\x12\x31.yamcs.protobuf.archive.StreamCommandIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"3\x8a\x92\x03/\x1a*/api/archive/{instance}:streamCommandIndex:\x01*0\x01\x12\x97\x01\n\x10StreamEventIndex\x12/.yamcs.protobuf.archive.StreamEventIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"1\x8a\x92\x03-\x1a(/api/archive/{instance}:streamEventIndex:\x01*0\x01\x12\xac\x01\n\x17StreamCompletenessIndex\x12\x36.yamcs.protobuf.archive.StreamCompletenessIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"8\x8a\x92\x03\x34\x1a//api/archive/{instance}:streamCompletenessIndex:\x01*0\x01\x12\x91\x01\n\x11RebuildCcsdsIndex\x12\x30.yamcs.protobuf.archive.RebuildCcsdsIndexRequest\x1a\x16.google.protobuf.Empty\"2\x8a\x92\x03.\x1a)/api/archive/{instance}:rebuildCcsdsIndex:\x01*B)\n\x12org.yamcs.protobufB\x11IndexServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTCOMMANDHISTORYINDEXREQUEST = _descriptor.Descriptor(
  name='ListCommandHistoryIndexRequest',
  full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=387,
)


_LISTEVENTINDEXREQUEST = _descriptor.Descriptor(
  name='ListEventIndexRequest',
  full_name='yamcs.protobuf.archive.ListEventIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListEventIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListEventIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListEventIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListEventIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListEventIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListEventIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListEventIndexRequest.source', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=580,
)


_LISTPACKETINDEXREQUEST = _descriptor.Descriptor(
  name='ListPacketIndexRequest',
  full_name='yamcs.protobuf.archive.ListPacketIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=772,
)


_LISTPARAMETERINDEXREQUEST = _descriptor.Descriptor(
  name='ListParameterIndexRequest',
  full_name='yamcs.protobuf.archive.ListParameterIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.group', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=968,
)


_LISTCOMPLETENESSINDEXREQUEST = _descriptor.Descriptor(
  name='ListCompletenessIndexRequest',
  full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.mergeTime', index=1,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.limit', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.start', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.stop', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.next', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1152,
)


_INDEXRESPONSE = _descriptor.Descriptor(
  name='IndexResponse',
  full_name='yamcs.protobuf.archive.IndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.IndexResponse.group', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.IndexResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1247,
)


_INDEXGROUP = _descriptor.Descriptor(
  name='IndexGroup',
  full_name='yamcs.protobuf.archive.IndexGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.archive.IndexGroup.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.archive.IndexGroup.entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1355,
)


_INDEXENTRY = _descriptor.Descriptor(
  name='IndexEntry',
  full_name='yamcs.protobuf.archive.IndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.IndexEntry.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.IndexEntry.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.IndexEntry.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStart', full_name='yamcs.protobuf.archive.IndexEntry.seqStart', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStop', full_name='yamcs.protobuf.archive.IndexEntry.seqStop', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1448,
)


_STREAMPACKETINDEXREQUEST = _descriptor.Descriptor(
  name='StreamPacketIndexRequest',
  full_name='yamcs.protobuf.archive.StreamPacketIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.mergeTime', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1451,
  serialized_end=1614,
)


_STREAMPARAMETERINDEXREQUEST = _descriptor.Descriptor(
  name='StreamParameterIndexRequest',
  full_name='yamcs.protobuf.archive.StreamParameterIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1768,
)


_STREAMCOMMANDINDEXREQUEST = _descriptor.Descriptor(
  name='StreamCommandIndexRequest',
  full_name='yamcs.protobuf.archive.StreamCommandIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1771,
  serialized_end=1920,
)


_STREAMEVENTINDEXREQUEST = _descriptor.Descriptor(
  name='StreamEventIndexRequest',
  full_name='yamcs.protobuf.archive.StreamEventIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=2070,
)


_STREAMCOMPLETENESSINDEXREQUEST = _descriptor.Descriptor(
  name='StreamCompletenessIndexRequest',
  full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.mergeTime', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2227,
)


_REBUILDCCSDSINDEXREQUEST = _descriptor.Descriptor(
  name='RebuildCcsdsIndexRequest',
  full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2359,
)

_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDEXRESPONSE.fields_by_name['group'].message_type = _INDEXGROUP
_INDEXGROUP.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_INDEXGROUP.fields_by_name['entry'].message_type = _INDEXENTRY
_STREAMPACKETINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPACKETINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENTINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENTINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMPLETENESSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMPLETENESSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDCCSDSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDCCSDSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListCommandHistoryIndexRequest'] = _LISTCOMMANDHISTORYINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListEventIndexRequest'] = _LISTEVENTINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListPacketIndexRequest'] = _LISTPACKETINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListParameterIndexRequest'] = _LISTPARAMETERINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListCompletenessIndexRequest'] = _LISTCOMPLETENESSINDEXREQUEST
DESCRIPTOR.message_types_by_name['IndexResponse'] = _INDEXRESPONSE
DESCRIPTOR.message_types_by_name['IndexGroup'] = _INDEXGROUP
DESCRIPTOR.message_types_by_name['IndexEntry'] = _INDEXENTRY
DESCRIPTOR.message_types_by_name['StreamPacketIndexRequest'] = _STREAMPACKETINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamParameterIndexRequest'] = _STREAMPARAMETERINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamCommandIndexRequest'] = _STREAMCOMMANDINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamEventIndexRequest'] = _STREAMEVENTINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamCompletenessIndexRequest'] = _STREAMCOMPLETENESSINDEXREQUEST
DESCRIPTOR.message_types_by_name['RebuildCcsdsIndexRequest'] = _REBUILDCCSDSINDEXREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCommandHistoryIndexRequest = _reflection.GeneratedProtocolMessageType('ListCommandHistoryIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDHISTORYINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCommandHistoryIndexRequest)
  })
_sym_db.RegisterMessage(ListCommandHistoryIndexRequest)

ListEventIndexRequest = _reflection.GeneratedProtocolMessageType('ListEventIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventIndexRequest)
  })
_sym_db.RegisterMessage(ListEventIndexRequest)

ListPacketIndexRequest = _reflection.GeneratedProtocolMessageType('ListPacketIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketIndexRequest)
  })
_sym_db.RegisterMessage(ListPacketIndexRequest)

ListParameterIndexRequest = _reflection.GeneratedProtocolMessageType('ListParameterIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterIndexRequest)
  })
_sym_db.RegisterMessage(ListParameterIndexRequest)

ListCompletenessIndexRequest = _reflection.GeneratedProtocolMessageType('ListCompletenessIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPLETENESSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCompletenessIndexRequest)
  })
_sym_db.RegisterMessage(ListCompletenessIndexRequest)

IndexResponse = _reflection.GeneratedProtocolMessageType('IndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _INDEXRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexResponse)
  })
_sym_db.RegisterMessage(IndexResponse)

IndexGroup = _reflection.GeneratedProtocolMessageType('IndexGroup', (_message.Message,), {
  'DESCRIPTOR' : _INDEXGROUP,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexGroup)
  })
_sym_db.RegisterMessage(IndexGroup)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)

StreamPacketIndexRequest = _reflection.GeneratedProtocolMessageType('StreamPacketIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPACKETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamPacketIndexRequest)
  })
_sym_db.RegisterMessage(StreamPacketIndexRequest)

StreamParameterIndexRequest = _reflection.GeneratedProtocolMessageType('StreamParameterIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPARAMETERINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamParameterIndexRequest)
  })
_sym_db.RegisterMessage(StreamParameterIndexRequest)

StreamCommandIndexRequest = _reflection.GeneratedProtocolMessageType('StreamCommandIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMMANDINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamCommandIndexRequest)
  })
_sym_db.RegisterMessage(StreamCommandIndexRequest)

StreamEventIndexRequest = _reflection.GeneratedProtocolMessageType('StreamEventIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENTINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamEventIndexRequest)
  })
_sym_db.RegisterMessage(StreamEventIndexRequest)

StreamCompletenessIndexRequest = _reflection.GeneratedProtocolMessageType('StreamCompletenessIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMPLETENESSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamCompletenessIndexRequest)
  })
_sym_db.RegisterMessage(StreamCompletenessIndexRequest)

RebuildCcsdsIndexRequest = _reflection.GeneratedProtocolMessageType('RebuildCcsdsIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDCCSDSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.RebuildCcsdsIndexRequest)
  })
_sym_db.RegisterMessage(RebuildCcsdsIndexRequest)


DESCRIPTOR._options = None

_INDEXESAPI = _descriptor.ServiceDescriptor(
  name='IndexesApi',
  full_name='yamcs.protobuf.archive.IndexesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2362,
  serialized_end=4130,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCommandHistoryIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListCommandHistoryIndex',
    index=0,
    containing_service=None,
    input_type=_LISTCOMMANDHISTORYINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003\'\n%/api/archive/{instance}/command-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListEventIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListEventIndex',
    index=1,
    containing_service=None,
    input_type=_LISTEVENTINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003%\n#/api/archive/{instance}/event-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListPacketIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListPacketIndex',
    index=2,
    containing_service=None,
    input_type=_LISTPACKETINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003&\n$/api/archive/{instance}/packet-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListParameterIndex',
    index=3,
    containing_service=None,
    input_type=_LISTPARAMETERINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003)\n\'/api/archive/{instance}/parameter-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListCompletenessIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListCompletenessIndex',
    index=4,
    containing_service=None,
    input_type=_LISTCOMPLETENESSINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003,\n*/api/archive/{instance}/completeness-index',
  ),
  _descriptor.MethodDescriptor(
    name='StreamPacketIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamPacketIndex',
    index=5,
    containing_service=None,
    input_type=_STREAMPACKETINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003.\032)/api/archive/{instance}:streamPacketIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamParameterIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamParameterIndex',
    index=6,
    containing_service=None,
    input_type=_STREAMPARAMETERINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\0031\032,/api/archive/{instance}:streamParameterIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCommandIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamCommandIndex',
    index=7,
    containing_service=None,
    input_type=_STREAMCOMMANDINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003/\032*/api/archive/{instance}:streamCommandIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamEventIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamEventIndex',
    index=8,
    containing_service=None,
    input_type=_STREAMEVENTINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003-\032(/api/archive/{instance}:streamEventIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCompletenessIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamCompletenessIndex',
    index=9,
    containing_service=None,
    input_type=_STREAMCOMPLETENESSINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\0034\032//api/archive/{instance}:streamCompletenessIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='RebuildCcsdsIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.RebuildCcsdsIndex',
    index=10,
    containing_service=None,
    input_type=_REBUILDCCSDSINDEXREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003.\032)/api/archive/{instance}:rebuildCcsdsIndex:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_INDEXESAPI)

DESCRIPTOR.services_by_name['IndexesApi'] = _INDEXESAPI

# @@protoc_insertion_point(module_scope)
