# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/commands_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/commands_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024CommandsServiceProtoP\001',
  serialized_pb=b'\n0yamcs/protobuf/commanding/commands_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xd3\x01\n\x13ListCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x03pos\x18\x02 \x01(\x03\x42\x02\x18\x01\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\x12\t\n\x01q\x18\x05 \x01(\t\x12\x0c\n\x04next\x18\x06 \x01(\t\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05queue\x18\t \x01(\t\"\xd5\x05\n\x13IssueCommandRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12%\n\x04\x61rgs\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Q\n\nassignment\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.commanding.IssueCommandRequest.AssignmentB\x02\x18\x01\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x0e\n\x06stream\x18\x0b \x01(\t\x12&\n\x1e\x64isableTransmissionConstraints\x18\x0c \x01(\x08\x12\x18\n\x10\x64isableVerifiers\x18\r \x01(\x08\x12Z\n\x0everifierConfig\x18\x0e \x03(\x0b\x32\x42.yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry\x12H\n\x05\x65xtra\x18\x0f \x03(\x0b\x32\x39.yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a`\n\x13VerifierConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).yamcs.protobuf.commanding.VerifierConfig:\x02\x38\x01\x1a\x43\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value:\x02\x38\x01\"\xa1\x03\n\x14IssueCommandResponse\x12\n\n\x02id\x18\x05 \x01(\t\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x08 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\t \x01(\t\x12M\n\x07\x61liases\x18\x0e \x03(\x0b\x32<.yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry\x12\x41\n\x0b\x61ssignments\x18\x0c \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x12\x19\n\x11unprocessedBinary\x18\r \x01(\x0c\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12\r\n\x05queue\x18\n \x01(\t\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x1bUpdateCommandHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x46\n\nattributes\x18\x05 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute\"p\n\x14ListCommandsResponse\x12=\n\x05\x65ntry\x18\x01 \x03(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"1\n\x11GetCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"4\n\x14\x45xportCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x8c\x01\n\x15StreamCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x03(\t\"[\n\x18SubscribeCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x1a\n\x12ignorePastCommands\x18\x03 \x01(\x08\x32\xee\x08\n\x0b\x43ommandsApi\x12\xb1\x01\n\x0cIssueCommand\x12..yamcs.protobuf.commanding.IssueCommandRequest\x1a/.yamcs.protobuf.commanding.IssueCommandResponse\"@\x8a\x92\x03<\x1a\x37/api/processors/{instance}/{processor}/commands/{name*}:\x01*\x12\xae\x01\n\x14UpdateCommandHistory\x12\x36.yamcs.protobuf.commanding.UpdateCommandHistoryRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a=/api/processors/{instance}/{processor}/commandhistory/{name*}:\x01*\x12\x97\x01\n\x0cListCommands\x12..yamcs.protobuf.commanding.ListCommandsRequest\x1a/.yamcs.protobuf.commanding.ListCommandsResponse\"&\x8a\x92\x03\"\n /api/archive/{instance}/commands\x12\x97\x01\n\nGetCommand\x12,.yamcs.protobuf.commanding.GetCommandRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"+\x8a\x92\x03\'\n%/api/archive/{instance}/commands/{id}\x12\xac\x01\n\x0eStreamCommands\x12\x30.yamcs.protobuf.commanding.StreamCommandsRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"6\x8a\x92\x03\x32\x1a-/api/stream-archive/{instance}:streamCommands:\x01*0\x01\x12\x8a\x01\n\x11SubscribeCommands\x12\x33.yamcs.protobuf.commanding.SubscribeCommandsRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"\x0e\xda\x92\x03\n\n\x08\x63ommands0\x01\x12\x89\x01\n\rExportCommand\x12/.yamcs.protobuf.commanding.ExportCommandRequest\x1a\x13.yamcs.api.HttpBody\"2\x8a\x92\x03.\n,/api/archive/{instance}/commands/{id}:exportB,\n\x12org.yamcs.protobufB\x14\x43ommandsServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTCOMMANDSREQUEST = _descriptor.Descriptor(
  name='ListCommandsRequest',
  full_name='yamcs.protobuf.commanding.ListCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.commanding.ListCommandsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.commanding.ListCommandsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.commanding.ListCommandsRequest.order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.commanding.ListCommandsRequest.q', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.commanding.ListCommandsRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.ListCommandsRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.ListCommandsRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.ListCommandsRequest.queue', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=510,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1071,
)

_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY = _descriptor.Descriptor(
  name='VerifierConfigEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1169,
)

_ISSUECOMMANDREQUEST_EXTRAENTRY = _descriptor.Descriptor(
  name='ExtraEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1238,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.IssueCommandRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.IssueCommandRequest.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.IssueCommandRequest.name', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.commanding.IssueCommandRequest.args', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.commanding.IssueCommandRequest.assignment', index=4,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.IssueCommandRequest.origin', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.IssueCommandRequest.sequenceNumber', index=6,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.commanding.IssueCommandRequest.dryRun', index=7,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.commanding.IssueCommandRequest.comment', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.commanding.IssueCommandRequest.stream', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disableTransmissionConstraints', full_name='yamcs.protobuf.commanding.IssueCommandRequest.disableTransmissionConstraints', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disableVerifiers', full_name='yamcs.protobuf.commanding.IssueCommandRequest.disableVerifiers', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifierConfig', full_name='yamcs.protobuf.commanding.IssueCommandRequest.verifierConfig', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.commanding.IssueCommandRequest.extra', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY, _ISSUECOMMANDREQUEST_EXTRAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=1238,
)


_ISSUECOMMANDRESPONSE_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1658,
)

_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.commanding.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.IssueCommandResponse.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.IssueCommandResponse.generationTime', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.IssueCommandResponse.origin', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.IssueCommandResponse.sequenceNumber', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.IssueCommandResponse.commandName', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.commanding.IssueCommandResponse.aliases', index=5,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.IssueCommandResponse.assignments', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unprocessedBinary', full_name='yamcs.protobuf.commanding.IssueCommandResponse.unprocessedBinary', index=7,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.commanding.IssueCommandResponse.binary', index=8,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.IssueCommandResponse.username', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.IssueCommandResponse.queue', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDRESPONSE_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1658,
)


_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.attributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1825,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.commanding.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.commanding.ListCommandsResponse.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.commanding.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1939,
)


_GETCOMMANDREQUEST = _descriptor.Descriptor(
  name='GetCommandRequest',
  full_name='yamcs.protobuf.commanding.GetCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.GetCommandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1941,
  serialized_end=1990,
)


_EXPORTCOMMANDREQUEST = _descriptor.Descriptor(
  name='ExportCommandRequest',
  full_name='yamcs.protobuf.commanding.ExportCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ExportCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.ExportCommandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2044,
)


_STREAMCOMMANDSREQUEST = _descriptor.Descriptor(
  name='StreamCommandsRequest',
  full_name='yamcs.protobuf.commanding.StreamCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2047,
  serialized_end=2187,
)


_SUBSCRIBECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SubscribeCommandsRequest',
  full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignorePastCommands', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.ignorePastCommands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2280,
)

_LISTCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._VERIFIERCONFIG
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST_EXTRAENTRY.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_ISSUECOMMANDREQUEST_EXTRAENTRY.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDREQUEST.fields_by_name['verifierConfig'].message_type = _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY
_ISSUECOMMANDREQUEST.fields_by_name['extra'].message_type = _ISSUECOMMANDREQUEST_EXTRAENTRY
_ISSUECOMMANDRESPONSE_ALIASESENTRY.containing_type = _ISSUECOMMANDRESPONSE
_ISSUECOMMANDRESPONSE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ISSUECOMMANDRESPONSE.fields_by_name['aliases'].message_type = _ISSUECOMMANDRESPONSE_ALIASESENTRY
_ISSUECOMMANDRESPONSE.fields_by_name['assignments'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDASSIGNMENT
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['attributes'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYATTRIBUTE
_LISTCOMMANDSRESPONSE.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_STREAMCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListCommandsRequest'] = _LISTCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['GetCommandRequest'] = _GETCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['ExportCommandRequest'] = _EXPORTCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['StreamCommandsRequest'] = _STREAMCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeCommandsRequest'] = _SUBSCRIBECOMMANDSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCommandsRequest = _reflection.GeneratedProtocolMessageType('ListCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsRequest)
  })
_sym_db.RegisterMessage(ListCommandsRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), {

  'Assignment' : _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_ASSIGNMENT,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.Assignment)
    })
  ,

  'VerifierConfigEntry' : _reflection.GeneratedProtocolMessageType('VerifierConfigEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry)
    })
  ,

  'ExtraEntry' : _reflection.GeneratedProtocolMessageType('ExtraEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_EXTRAENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest)
  })
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)
_sym_db.RegisterMessage(IssueCommandRequest.VerifierConfigEntry)
_sym_db.RegisterMessage(IssueCommandRequest.ExtraEntry)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDRESPONSE_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandResponse)
  })
_sym_db.RegisterMessage(IssueCommandResponse)
_sym_db.RegisterMessage(IssueCommandResponse.AliasesEntry)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.UpdateCommandHistoryRequest)
  })
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsResponse)
  })
_sym_db.RegisterMessage(ListCommandsResponse)

GetCommandRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetCommandRequest)
  })
_sym_db.RegisterMessage(GetCommandRequest)

ExportCommandRequest = _reflection.GeneratedProtocolMessageType('ExportCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ExportCommandRequest)
  })
_sym_db.RegisterMessage(ExportCommandRequest)

StreamCommandsRequest = _reflection.GeneratedProtocolMessageType('StreamCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.StreamCommandsRequest)
  })
_sym_db.RegisterMessage(StreamCommandsRequest)

SubscribeCommandsRequest = _reflection.GeneratedProtocolMessageType('SubscribeCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.SubscribeCommandsRequest)
  })
_sym_db.RegisterMessage(SubscribeCommandsRequest)


DESCRIPTOR._options = None
_LISTCOMMANDSREQUEST.fields_by_name['pos']._options = None
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY._options = None
_ISSUECOMMANDREQUEST_EXTRAENTRY._options = None
_ISSUECOMMANDREQUEST.fields_by_name['assignment']._options = None
_ISSUECOMMANDRESPONSE_ALIASESENTRY._options = None

_COMMANDSAPI = _descriptor.ServiceDescriptor(
  name='CommandsApi',
  full_name='yamcs.protobuf.commanding.CommandsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2283,
  serialized_end=3417,
  methods=[
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.IssueCommand',
    index=0,
    containing_service=None,
    input_type=_ISSUECOMMANDREQUEST,
    output_type=_ISSUECOMMANDRESPONSE,
    serialized_options=b'\212\222\003<\0327/api/processors/{instance}/{processor}/commands/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommandHistory',
    full_name='yamcs.protobuf.commanding.CommandsApi.UpdateCommandHistory',
    index=1,
    containing_service=None,
    input_type=_UPDATECOMMANDHISTORYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032=/api/processors/{instance}/{processor}/commandhistory/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.ListCommands',
    index=2,
    containing_service=None,
    input_type=_LISTCOMMANDSREQUEST,
    output_type=_LISTCOMMANDSRESPONSE,
    serialized_options=b'\212\222\003\"\n /api/archive/{instance}/commands',
  ),
  _descriptor.MethodDescriptor(
    name='GetCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.GetCommand',
    index=3,
    containing_service=None,
    input_type=_GETCOMMANDREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\003\'\n%/api/archive/{instance}/commands/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.StreamCommands',
    index=4,
    containing_service=None,
    input_type=_STREAMCOMMANDSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\0032\032-/api/stream-archive/{instance}:streamCommands:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.SubscribeCommands',
    index=5,
    containing_service=None,
    input_type=_SUBSCRIBECOMMANDSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\332\222\003\n\n\010commands',
  ),
  _descriptor.MethodDescriptor(
    name='ExportCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.ExportCommand',
    index=6,
    containing_service=None,
    input_type=_EXPORTCOMMANDREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\003.\n,/api/archive/{instance}/commands/{id}:export',
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMANDSAPI)

DESCRIPTOR.services_by_name['CommandsApi'] = _COMMANDSAPI

# @@protoc_insertion_point(module_scope)
